@@ -1,3 +1,9 @@
+# --------------------------------------------------- #
+# Author: Marius D. Pascariu
+# License: MIT
+# Last update: Thu Nov 07 11:50:34 2019
+# --------------------------------------------------- #
+
 
 #' Objective function
 #' @param L lambda.hat
@@ -6,11 +12,23 @@
 ofun <- function(L, I, type) {
   L <- round(exp(L), 6)
   with(I$control, {
-    M <- pclm.fit(I$x, I$y, I$nlast, I$offset, I$out.step, verbose = FALSE, 
-                  lambda = L, kr, deg, diff, max.iter, tol, type)
-    fn <- paste0(opt.method, ".pclm")
+    M <- pclm.fit(x        = I$x, 
+                  y        = I$y, 
+                  nlast    = I$nlast, 
+                  offset   = I$offset, 
+                  out.step = I$out.step, 
+                  verbose  = FALSE, 
+                  lambda   = L, 
+                  kr       = kr, 
+                  deg      = deg, 
+                  diff     = diff, 
+                  max.iter = max.iter, 
+                  tol      = tol, 
+                  type     = type)
+    
+    fn      <- paste0(opt.method, ".pclm")
     aic_bic <- get(fn)
-    out <- aic_bic(M)
+    out     <- aic_bic(M)
     # print(round(c(L = L, AIC = out), 3))
     return(out)
   })
@@ -35,8 +53,11 @@ optimize_par <- function(I, type) {
       if (I$verbose) {setpb(pb, 40); cat("   Optimizing lambda  ")}
       
       if (type == "1D") {
-        opt <- optimise(f = ofun, interval = log(int.lambda), I = I, 
-                        type = type, tol = 1e-05)
+        opt <- optimise(f    = ofun, 
+                        interval = log(int.lambda), 
+                        I    = I, 
+                        type = type, 
+                        tol  = 1e-05)
         lambda.hat <- round(exp(opt$minimum), 6)
         
       } else {
